@@ -22,6 +22,8 @@ for cfgfile in access.conf httpd.conf magic mime.types srm.conf ; do
    fi
 done
 ( cd usr/lib ; rm -rf libmm.so )
-( cd usr/lib ; ln -sf libmm.so.12.0.22 libmm.so )
-( cd usr/lib ; rm -rf libmm.so.12 )
-( cd usr/lib ; ln -sf libmm.so.12.0.22 libmm.so.12 )
+( cd usr/lib ; ln -sf libmm.so.13.0.20 libmm.so )
+( cd usr/lib ; rm -rf libmm.so.13 )
+( cd usr/lib ; ln -sf libmm.so.13.0.20 libmm.so.13 )
+( cd usr/sbin ; rm -rf apachectl )
+( cd usr/sbin ; ln -sf apachectl-standard apachectl )
